@@ -108,27 +108,20 @@ class DiscreteEnv(gym.Env):
 
     self.Ynew_cumul = np.mean(Prob1)
     #reduce the horizon
-    #self.horizon -= 1
-    
-    #depending on the value of self.state, apply a reward
-    #done = np.any(Prob1 < 0.2)    
-    reward = 0
+    self.horizon -= 1
     
+      
     #if done:
       #reward = self.Ynew_cumul 
     
     done = bool(self.horizon <= 0)
-    if done:
-      reward = self.Ynew_cumul
+    reward = self.Ynew_cumul
+       
+    #check if horizon is over, otherwise keep on doing
+    if self.horizon <= 0:
+        done = True
     else:
-      done = False 
-    
-    
-    #check if horion is over, otherwise keep on doing
-    #if self.horizon <= 0:
-     #   done = True
-    #else:
-     #   done = False
+        done = False
 
     #set placeholder for infos
     info ={}        
